pub struct TransportContent {
pub transport_header: Box<TransportHeader>,
pub transport_details: Box<TransportDetailOutput>,
pub transport_result: Box<TransportResult>,
}Expand description
TransportContent : Inbound shipment information, including carrier details, shipment status, and the workflow status for a request for shipment with an Amazon-partnered carrier.
Fields
transport_header: Box<TransportHeader>transport_details: Box<TransportDetailOutput>transport_result: Box<TransportResult>Implementations
sourceimpl TransportContent
impl TransportContent
sourcepub fn new(
transport_header: TransportHeader,
transport_details: TransportDetailOutput,
transport_result: TransportResult
) -> TransportContent
pub fn new(
transport_header: TransportHeader,
transport_details: TransportDetailOutput,
transport_result: TransportResult
) -> TransportContent
Inbound shipment information, including carrier details, shipment status, and the workflow status for a request for shipment with an Amazon-partnered carrier.